# lgm

LGM is a lightweight python3 library for natural LanGuage Modeling (LGM), useful for deep learning and reinforcement learning experiments with natural language data.

Originally, the code was based partly on code from the fastai course v3, dl2 (March-April 2019), and partly on code from the University of Alberta Reinforcement Learning specialization (Coursera, fall 2019).

To install:

pip3 install lgm
